@@ -30,76 +30,78 @@
 
 =head2 Example Cases
 
-CASE 1A
+ CASE 1A
 
-Use a list (use complete file names but exclude the directory paths) 
-for concatenating iVelan "pick files" (Vrms,time pairs)
-into the correct format.
+ Use a list (use complete file names but exclude the directory paths) 
+ for concatenating iVelan "pick files" (Vrms,time pairs)
+ into the correct format.
 
-A "list", which is found in the $PL_SEISMIC directory contains, 
-e.g.:
-ivpicks_sorted_par_L28Hz_Ibeam_geom4_cdp1
-ivpicks_sorted_par_L28Hz_Ibeam_geom4_cdp11
+ A "list", which is found in the $DATA_SEISMIC_TXT directory contains, 
+ e.g.:
+ ivpicks_sorted_par_L28Hz_Ibeam_geom4_cdp1
+ ivpicks_sorted_par_L28Hz_Ibeam_geom4_cdp11
 
-The starting input format in "par" format is as follows:
+ The starting input format in "par" format is as follows:
 
-(for ivpicks_sorted_par_L28Hz_Ibeam_geom4_cdp1)
-tnmo=0.0189974,0.113193,0.153562,0.231926
-vnmo=59.4778,160.806,195.689,273.761
+ (for ivpicks_sorted_par_L28Hz_Ibeam_geom4_cdp1)
+ tnmo=0.0189974,0.113193,0.153562,0.231926
+ vnmo=59.4778,160.806,195.689,273.761
 
-(for ivpicks_sorted_par_L28Hz_Ibeam_geom4_cdp11)
-tnmo=0.0316623,0.0759894,0.129815
-vnmo=101.006,130.906,263.794
+ (for ivpicks_sorted_par_L28Hz_Ibeam_geom4_cdp11)
+ tnmo=0.0316623,0.0759894,0.129815
+ vnmo=101.006,130.906,263.794
 
-The final output format is:
+ The final output format is:
 
-cdp=3,5
-tnmo=0.0189974,0.113193,0.153562,0.231926
-vnmo=59.4778,160.806,195.689,273.761
-tnmo=0.0316623,0.0759894,0.129815
-vnmo=101.006,130.906,263.794
+ cdp=3,5
+ tnmo=0.0189974,0.113193,0.153562,0.231926
+ vnmo=59.4778,160.806,195.689,273.761
+ tnmo=0.0316623,0.0759894,0.129815
+ vnmo=101.006,130.906,263.794
 
 
 CASE 1B
 
-Use a list (use complete file names but exclude the directory paths) 
-for concatenating iVelan "pick files" (x-coordinate,time pairs)
-into the correct format.
+ Use a list (use complete file names but exclude the directory paths) 
+ for concatenating iVelan "pick files" (x-coordinate,time pairs)
+ into the correct format.
 
-A "list" which is found in the $PL_SEISMIC directory contains, e.g.:
+ A "list" which is found in the $DATA_SEISMIC_TXT directory contains, e.g.:
 
-itop_mute_par_L28Hz_Ibeam_cmp_ep3
-itop_mute_par_L28Hz_Ibeam_cmp_ep5
+ itop_mute_par_L28Hz_Ibeam_cmp_ep3
+ itop_mute_par_L28Hz_Ibeam_cmp_ep5
 
 
-The starting input format in each  in "par" format:
-tnmo=0.0189974,0.113193,0.153562,0.231926
-vnmo=59.4778,160.806,195.689,273.761
+ The starting input format in each  in "par" format:
+ tnmo=0.0189974,0.113193,0.153562,0.231926
+ vnmo=59.4778,160.806,195.689,273.761
 
-The final output format is:
+ tmute=0.0189974,0.113193,0.153562,0.231926
+ xmute=5.4778,16.806,19.68,100.761
 
+ The final output format is:
 
-The list is expected to be found in $PL_SEISMIC, i.e., ~/pl/"subuser"/
+ The list is expected to be found in $DATA_SEISMIC_TXT, i.e., ~/txt/"subuser"/
     
  Data_type is determined by parsing the file names and normally contains:
  "itop_mute", "ibot_mute" etc." '
     
-(See ~sunix/shell/sucat.pm
-If "data_type" = "velan" then the concatenated output file
-will automatically be reformatted for input into sunmo.       
+ (See ~sunix/shell/sucat.pm
+ If "data_type" = "velan" then the concatenated output file
+ will automatically be reformatted for input into sunmo.       
 
-If "data_type" = "itop_mute" or "ibot_mute" then the concatenated 
-output file will automatically be reformatted for input into
-"sumute". 
+ If "data_type" = "itop_mute" or "ibot_mute" then the concatenated 
+ output file will automatically be reformatted for input into
+ "sumute". 
 
 GUI EXAMPLE:    
     
-Note that a list can only be used when the values of the prior
-6 parameters are blank.
+ Note that a list can only be used when the values of the prior
+ 6 parameters are blank.
 
-An output name is also required.
---Exclude values for first 7 parameters in GUI. 
---alternative directories are optional.
+ An output name is also required.
+ --Exclude values for first 7 parameters in GUI. 
+ --alternative directories are optional.
 
     first_file_number_in               =               
     last_file_number_in                =                
@@ -107,13 +109,13 @@ An output name is also required.
     input_suffix                       =               
     input_name_prefix                  =                  
     input_name_extension               =              
-    list                               =  file name [$PL_SEISMIC]
+    list                               =  file name [$DATA_SEISMIC_TXT]
     output_file_name                   =    
     alternative_inbound_directory      =  [$PL_SEISMIC]             
     alternative_outbound_directory     =  [$PL_SEISMIC]  
   
   
-  and exmample list
+  an example list:
   
   25.su
   26.su
@@ -122,17 +124,21 @@ An output name is also required.
 ---------------------------------------------------------------------------
 
 CASE 2
-General concatenation of files with patterns in their names
+ General concatenation of files with patterns in their names
 
-DO NOT use a list. 
-Instead, include values for at least the first 3 
-parameters in the GUI, 
-and up to and including values for all the remaining parameters,
-except the list name. A
+ DO NOT use a list. 
+ Instead, include values for at least the first 3 
+ parameters in the GUI, 
+ and up to and including values for all the remaining parameters,
+ except the list name. A
 
-An output name is possible but not required.
+ An output name is possible but not required. Note that it is assumed
+ that the suffix and therefore directory of the output file has the
+ same origin directory as the input files.  The input suffix is used
+ to determine the origin directory. For example an su input suffix will
+ point to a $DATA_SEISMIC_SU directory.
  
-Example:
+ Example:
   
     first_file_number_in                = 1000                
     last_file_number_in                 = 1001                
@@ -145,7 +151,7 @@ Example:
     alternative_inbound_directory       =                   
     alternative_outbound_directory      =  
     
-    The above case will produce carries out the following isntruction
+    The above case will produce carries out the following instruction:
     
     cat DIR1/cdp1000_clean.su DIR1/cdp1001_clean.su > DIR2/1000_01.su 
    
@@ -163,21 +169,21 @@ Example:
     
 CASE 3
   
-	If you want to use a list, the list
-	is a file that contains one
-	or more file names
+ If you want to use a list, the list
+ is a file that contains one
+ or more file names
 
 
-	first_file_number_in                  = 
-	last_file_number_in                   = 
-	number_of_files_in                    = 
-	input_suffix                          = 
-	input_name_prefix                     = 
-	input_name_extension                  = 
-	list                                  = cat_list_good_sp;
-	output_file_name                      = 'All_good_sp';
-	alternative_inbound_directory         = 
-	alternative_outbound_directory        =
+ first_file_number_in                  = 
+ last_file_number_in                   = 
+ number_of_files_in                    = 
+ input_suffix                          = 
+ input_name_prefix                     = 
+ input_name_extension                  = 
+ list                                  = cat_list_good_sp;
+ output_file_name                      = 'All_good_sp';
+ alternative_inbound_directory         = 
+ alternative_outbound_directory        =
 
 
  CASE 4:
@@ -194,12 +200,12 @@ CASE 3
 
 =head2 NOTES 
 
-   The input and output default directories are $PL_SEISMIC
-   but these can be overridden by the values of the 
-   alternative directories
+  The input and output default directories are $PL_SEISMIC
+  but these can be overridden by the values of the 
+  alternative directories
     
  
- =head2 CHANGES
+=head2 CHANGES
  
   V 0.1.2 considers empty file_names May 30, 2019; NM
   V 0.1.3 includes additional concatenation for:
@@ -220,7 +226,7 @@ use aliased 'App::SeismicUnixGui::misc::message';
 use aliased 'App::SeismicUnixGui::sunix::shell::sucat';
 use aliased 'App::SeismicUnixGui::misc::manage_files_by';
 use App::SeismicUnixGui::misc::SeismicUnix
-  qw($_cdp $_mute $in $itop_mute_par_ $ivpicks_sorted_par_ $out $on $go $to $suffix_ascii $off $suffix_su);
+  qw($_cdp $_mute $in $itop_mute_par_ $ivpicks_sorted_par_ $out $on $go $to $suffix_ascii $off $suffix_su $suffix_txt);
 use aliased 'App::SeismicUnixGui::misc::L_SU_global_constants';
 use aliased 'App::SeismicUnixGui::configs::big_streams::Sucat_config';
 use aliased 'App::SeismicUnixGui::specs::big_streams::Sucat_specB';
@@ -231,12 +237,13 @@ use aliased 'App::SeismicUnixGui::specs::big_streams::Sucat_specB';
 
 =cut
 
-my ( @file_out, @flow, @items, @cat, @sufile_out, @outbound );
+my ( @file_out, @flow, @items, @cat, @sufile_out );
 my $outbound_directory;
 my $inbound_directory;
 my ( @ref_array, @sucat );
 my $ref_array;
 my $num_cdps;
+my $outbound;
 
 =head2 2. Instantiate classes:
 
@@ -259,20 +266,21 @@ my $Sucat_config = Sucat_config->new();
 
 Establish default variables using a *_spec file
 and defaults defined hereinf or the location of the list file;
-in PL_SEISMIC
+in DATA_SEISMIC_TXT
 
 =cut
 
 my ( $CFG_h, $CFG_aref ) = $Sucat_config->get_values();
 my $Sucat_spec_variables = $Sucat_specB->variables();
 
-my $DATA_DIR_IN  = $Sucat_spec_variables->{_DATA_DIR_IN};
-my $DATA_DIR_OUT = $Sucat_spec_variables->{_DATA_DIR_OUT};
-my $PL_SEISMIC   = $Project->PL_SEISMIC;
+# defaults are for su-type data
+my $DATA_DIR_IN_default  = $Sucat_spec_variables->{_DATA_DIR_IN};
+my $DATA_DIR_OUT_default = $Sucat_spec_variables->{_DATA_DIR_OUT};
+my $DATA_SEISMIC_TXT     = $Project->DATA_SEISMIC_TXT;
 
-my $inbound_directory_default  = $DATA_DIR_IN;
-my $outbound_directory_default = $DATA_DIR_OUT;
-my $list_directory_default     = $PL_SEISMIC;
+my $inbound_directory_default  = $DATA_DIR_IN_default;
+my $outbound_directory_default = $DATA_DIR_OUT_default;
+my $list_directory_default     = $DATA_SEISMIC_TXT;
 
 $inbound_directory  = $inbound_directory_default;
 $outbound_directory = $outbound_directory_default;
@@ -321,7 +329,8 @@ $alternative_outbound_directory =
 $list = $control->get_no_quotes($list);
 
 # print("Sucat.pl, list: $list\n\n");
-# print("Sucat.pl, list: $data_type\n\n");
+# print("Sucat.pl, output_file_name: $output_file_name\n\n");
+# print("Sucat.pl, outbound_directory: $outbound_directory\n\n");
 
 =head2 3. Consider compatible
 
@@ -330,7 +339,6 @@ a list
 
 =cut
 
-
 # CASE 1: new inbound and or/outbound directories replace defaults
 if ( $alternative_outbound_directory ne $empty_string ) {
 
@@ -343,17 +351,17 @@ elsif ( $alternative_outbound_directory eq $empty_string ) {
 
 	if ( $list ne $empty_string ) {
 
-		$outbound_directory = $list_directory_default;
+		$outbound_directory = $DATA_DIR_OUT_default;
 
 	}
 	else {
-		$outbound_directory = $DATA_DIR_OUT;
+		$outbound_directory = $DATA_DIR_OUT_default;
 	}
 
-	# print("2. Sucat.pl, selected outbound_directory $outbound_directory  \n");
+   # print("2. Sucat.pl, selected outbound_directory $outbound_directory  \n");
 }
 else {
-	print("Sucat.pl, unexpected alternative_outbound_directory  \n");
+	# print("Sucat.pl, unexpected alternative_outbound_directory  \n");
 }
 
 if ( $alternative_inbound_directory ne $empty_string ) {
@@ -372,7 +380,7 @@ elsif ( $alternative_inbound_directory eq $empty_string ) {
 
 	}
 	else {
-		$inbound_directory = $DATA_DIR_IN;
+		#NADA $inbound_directory = $DATA_DIR_IN_default;
 	}
 
 	# print("4. Sucat.pl, selected inbound_directory=$inbound_directory  \n");
@@ -381,8 +389,8 @@ else {
 	print("Sucat.pl, unexpected alternative_inbound_directory  \n");
 }
 
-#print("Sucat.pl,inbound_directory:---$inbound_directory--\n");
-#print("Sucat.pl,outbound_directory:---$outbound_directory--\n");
+# print("Sucat.pl,inbound_directory:---$inbound_directory--\n");
+# print("Sucat.pl,outbound_directory:---$outbound_directory--\n");
 
 =head2 3. Declare output file names and their paths
 
@@ -391,21 +399,29 @@ else {
 
 =cut
 
-$file_out[1] = $output_file_name;
+$file_out[1] = $output_file_name;    # always needed
 
-if ( $input_suffix ne $empty_string ) {
+if ( length $output_file_name ) {
+	
+	if ( $input_suffix ne $empty_string ) {
 
-	$outbound[1] =
-	  $outbound_directory . '/' . $file_out[1] . '.' . $input_suffix;
+		$outbound =
+		  $outbound_directory . '/' . $file_out[1] . '.' . $input_suffix;
 
-}
-elsif ( $input_suffix eq $empty_string ) {
+	}
+	elsif ( $input_suffix eq $empty_string ) {
 
-	$outbound[1] = $outbound_directory . '/' . $file_out[1];
+		$outbound = $outbound_directory . '/' . $file_out[1];
 
+	}
+	else {
+		print("Sucat.pl,unexpected empty string\n");
+	}
+	
+	print("Sucat.pl,outbound=$outbound\n");
 }
 else {
-	print("Sucat.pl,unexpected empty string\n");
+	print("Sucat.pl, missing output  filename\n");
 }
 
 =header set up sucat
@@ -445,11 +461,14 @@ if (    $list ne $empty_string
 	and $input_name_extension eq $empty_string )
 {
 
-#	print("2. Sucat.pl, list:---$list---\n");
-#	print("2. Sucat.pl, list:---0:@$ref_array[0], 1:@$ref_array[1]\n");
-#	my $ans =scalar @$ref_array;
-#	print("2. Sucat.pl, num_rows---$ans\n");
-	my $inbound_list = $list_directory . '/' . $list;
+	#	print("2. Sucat.pl, list:---$list---\n");
+	#	print("2. Sucat.pl, list_directory:---$list_directory---\n");
+	#	print("2. Sucat.pl, list:---0:@$ref_array[0], 1:@$ref_array[1]\n");
+	#	my $ans =scalar @$ref_array;
+	#	print("2. Sucat.pl, num_rows---$ans\n");
+	my $inbound_list = $list_directory . '/' . $list . $suffix_txt;
+
+	#	print("1. Sucat.pl, inbound_list:---$inbound_list---\n");
 	( $ref_array, $num_cdps ) = $read->cols_1p($inbound_list);
 	$sucat->set_list_aref($ref_array);
 	$sucat->data_type();
@@ -482,11 +501,18 @@ else {
 
 $sucat[1] = $sucat->Step();
 
+# outbound includes a suffix if su data is detected
+# outbound also chooses DATA_SEISMIC_TXT path if
+# data_type = $txt
+
+$sucat->set_outbound($outbound);
+my $new_outbound = $sucat->get_outbound();
+
 =head2 A. DEFINE FLOW(S)
 
-=cut
+=cut 
 
-@items = ( $sucat[1], $out, $outbound[1], $go );
+@items   = ( $sucat[1], $out, $new_outbound, $go );
 
 $flow[1] = $run->modules( \@items );
 
@@ -503,5 +529,5 @@ $run->flow( \$flow[1] );
 $log->screen( $flow[1] );
 
 #my $time = localtime;
-#$log->file(time);
+#$log->time;
 #$log->file( $flow[1] );
