@@ -722,6 +722,8 @@ my $specifications_path_w_colon = {
 	  . $developer_sunix_categories[14],
 	_suifft => $global_libs_w_colon->{_specs} . '::'
 	  . $developer_sunix_categories[14],
+	_suminphase => $global_libs_w_colon->{_specs} . '::'
+	  . $developer_sunix_categories[14],
 	_suphasevel => $global_libs_w_colon->{_specs} . '::'
 	  . $developer_sunix_categories[14],
 	_suspecfk => $global_libs_w_colon->{_specs} . '::'
@@ -1338,6 +1340,8 @@ my $specifications_path_w_slash = {
 	  . $developer_sunix_categories[14],
 	_suifft => $global_libs_w_slash->{_specs} . '/'
 	  . $developer_sunix_categories[14],
+	_suminphase => $global_libs_w_slash->{_specs} . '/'
+	  . $developer_sunix_categories[14],
 	_suphasevel => $global_libs_w_slash->{_specs} . '/'
 	  . $developer_sunix_categories[14],
 	_suspecfk => $global_libs_w_slash->{_specs} . '/'
