@@ -5,7 +5,7 @@ package App::SeismicUnixGui::misc::files_LSU;
 
 =head2 SYNOPSIS 
 
- PERL PACKAGE NAME: files_LSU
+ PERL PERL PROGRAM NAME: files_LSU
  AUTHOR: 	Juan Lorenzo
  DATE: 		May 6 2018
 
@@ -1322,7 +1322,7 @@ sub _write {
 	my $config_file_format_aref = _get_superflow_config_file_format_aref();
 	my $num_formats             = scalar @$config_file_format_aref;
 
-#	 print("files_LSU, _write,num_formats=$num_formats\n");
+	# print("files_LSU, _write,num_formats=$num_formats\n");
 
 	if ( $num_formats == 1 ) {
 
@@ -1330,7 +1330,7 @@ sub _write {
 
 			$format[$i] = @{$config_file_format_aref}[0];
 
-#			print("1. files_LSU,_write,$format[$i]\n");
+			# print("1. files_LSU,_write,$format[$i]\n");
 
 		}
 
